@@ -78,11 +78,12 @@ origin = origins.LoadBalancerV2Origin(load_balancer,
     connection_attempts=3,
     connection_timeout=Duration.seconds(5),
     read_timeout=Duration.seconds(45),
+    keepalive_timeout=Duration.seconds(45),
     protocol_policy=cloudfront.OriginProtocolPolicy.MATCH_VIEWER
 )
 ```
 
-Note that the `readTimeout` property can extend its value over 60 seconds only if a limit increase request for CloudFront origin response timeout
+Note that the `readTimeout` and `keepaliveTimeout` properties can extend their values over 60 seconds only if a limit increase request for CloudFront origin response timeout
 quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Consider that this value is
 still limited to a maximum value of 180 seconds, which is a hard limit for that quota.
 
@@ -182,7 +183,7 @@ class HttpOrigin(
         :param domain_name: -
         :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
         :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
-        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
+        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(5)
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
         :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
@@ -257,7 +258,7 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
         :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
-        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
+        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(5)
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
         :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
@@ -389,7 +390,10 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
     def keepalive_timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
         '''Specifies how long, in seconds, CloudFront persists its connection to the origin.
 
-        The valid range is from 1 to 60 seconds, inclusive.
+        The valid range is from 1 to 180 seconds, inclusive.
+
+        Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
+        has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
 
         :default: Duration.seconds(5)
         '''
@@ -491,7 +495,7 @@ class LoadBalancerV2Origin(
         :param load_balancer: -
         :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
         :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
-        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
+        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(5)
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
         :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
@@ -560,7 +564,7 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
         :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
-        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
+        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(5)
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
         :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
@@ -577,6 +581,7 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
                 connection_attempts=3,
                 connection_timeout=Duration.seconds(5),
                 read_timeout=Duration.seconds(45),
+                keepalive_timeout=Duration.seconds(45),
                 protocol_policy=cloudfront.OriginProtocolPolicy.MATCH_VIEWER
             )
         '''
@@ -681,7 +686,10 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
     def keepalive_timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
         '''Specifies how long, in seconds, CloudFront persists its connection to the origin.
 
-        The valid range is from 1 to 60 seconds, inclusive.
+        The valid range is from 1 to 180 seconds, inclusive.
+
+        Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
+        has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
 
         :default: Duration.seconds(5)
         '''
